netapp_ontap.models.volume_snaplock API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_snaplock`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeSnaplockSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeSnaplock object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `append_mode_enabled GET POST PATCH`

    Specifies if the volume append mode is enabled or disabled. When it is enabled, all the files created with write permissions on the volume are, by default, WORM appendable files. The user can append the data to a WORM appendable file but cannot modify the existing contents of the file nor delete the file until it expires.

    Example: false

  `autocommit_period GET POST PATCH`

    Specifies the autocommit period for SnapLock volume. All files which are not modified for a period greater than the autocommit period of the volume are committed to the WORM state. The autocommit period value represents a duration and must be specified in the ISO-8601 duration format. The autocommit period can be in years, months, days, hours, and minutes. A period specified for years, months, and days is represented in the ISO-8601 format as "PY", "PM", "PD" respectively, for example "P10Y" represents a duration of 10 years. A duration in hours and minutes is represented by "PTH" and "PTM" respectively. The period string must contain only a single time element that is, either years, months, days, hours, or minutes. A duration which combines different periods is not supported, for example "P1Y10M" is not supported. Apart from the duration specified in the ISO-8601 format, the autocommit field also accepts the string "none".

    Example: P30M

  `compliance_clock_time GET`

    This is the volume compliance clock time which is used to manage the SnapLock objects in the volume.

    Example: 2018-06-04T19:00:00.000+0000

  `expiry_time GET`

    Expiry time of the volume.

    Example: Wed Sep 5 11:02:42 GMT 2018

  `is_audit_log GET`

    Indicates if this volume has been configured as SnapLock audit log volume for the SVM .

    Example: true

  `litigation_count GET`

    Litigation count indicates the number of active legal-holds on the volume.

    Example: 10

  `privileged_delete GET POST PATCH`

    Specifies the privileged-delete attribute of a SnapLock volume. On a SnapLock Enterprise (SLE) volume, a designated privileged user can selectively delete files irrespective of the retention time of the file. SLE volumes can have privileged delete as disabled, enabled or permanently_disabled and for SnapLock Compliance (SLC) volumes it is always permanently_disabled.

    Valid choices:

    - disabled
    - enabled
    - permanently_disabled
  `retention GET POST PATCH`

    The retention field of the volume_snaplock.

  `type GET`

    The SnapLock type of the volume.
    compliance ‐ A SnapLock Compliance(SLC) volume provides the highest level of WORM protection and an administrator cannot destroy a SLC volume if it contains unexpired WORM files.
    enterprise ‐ An administrator can delete a SnapLock Enterprise(SLE) volume.
    non_snaplock ‐ Indicates the volume is non-snaplock.

    Valid choices:

    - compliance
    - enterprise
    - non_snaplock
  `unspecified_retention_file_count GET`

    Indicates the number of files with an unspecified retention time in the volume.

    Example: 10